using System;
using WingServerCommon.Log;
using WingServerCommon.Interfaces.OpLog;
namespace WingServerCommon.Interfaces.Cache
{
    public interface ILiveRoomsManager : IBaseCacheManager<CacheLiveRoomDTO>
    {

    }

    public class LiveRoomsManager : CacheManager<CacheLiveRoomDTO>, ILiveRoomsManager
    {
        public LiveRoomsManager() : base()
        {
        }
    }

    /// <summary>
    /// 房间信息
    /// </summary>
    public class CacheLiveRoomDTO : ICacheObject
    {
        /// <summary>
        /// 房间编码
        /// </summary>
        /// <value>fb6414d24e3c347d46032b0496f1c4e4</value>
        public string Code { get; set; } = string.Empty;

        /// <summary>
        /// 关联业务编码
        /// </summary>
        /// <value>rb6414d24e3c347d46032b0496f1c4e4</value>
        public string RelatedCode { get; set; } = string.Empty;

        /// <summary>
        /// 发起人编码
        /// </summary>
        /// <value>ub6414d24e3c347d46032b0496f1c4e4</value>
        public string InitiatorCode { get; set; } = string.Empty;

        /// <summary>
        /// 整型房间号
        /// </summary>
        /// <value>7001</value>
        public int IntegerRoomId { get; set; }

        /// <summary>
        /// 视频流协议
        /// </summary>
        /// <value>1</value>
        public int LiveProtocol { get; set; }

        /// <summary>
        /// 业务类型
        /// </summary>
        /// <value>1</value>
        public int BusinessModule { get; set; }

        /// <summary>
        /// 是否直播中
        /// </summary>
        /// <value>false</value>
        public bool Living { get; set; } = false;

        /// <summary>
        /// 最后解散时间
        /// </summary>
        /// <value></value>
        public DateTime? LastEndTime { get; set; }

        /// <summary>
        /// 已接入设备集合
        /// </summary>
        /// <value></value>
        public List<CacheLiveMemberDTO> DeviceInfos { get; set; } = new List<CacheLiveMemberDTO>();

        /// <summary>
        /// 已接入客户端用户集合
        /// </summary>
        /// <value></value>
        public List<CacheLiveMemberDTO> UserInfos { get; set; } = new List<CacheLiveMemberDTO>();
    }

    /// <summary>
    /// 会诊成员信息
    /// </summary>
    public class CacheLiveMemberDTO
    {
        /// <summary>
        /// 设备/用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string Code { get; set; } = string.Empty;

        /// <summary>
        /// 成员类型
        /// </summary>
        /// <value>UserDO_123456789</value>
        public int MemberType { get; set; }

        /// <summary>
        /// 设备/用户姓名
        /// </summary>
        /// <value>刘医生</value>
        public string Name { get; set; } = string.Empty;

        /// <summary>
        /// 是否静音
        /// </summary>
        /// <value>false</value>
        public bool MuteOpened { get; set; } = false;

        /// <summary>
        /// 是否开启视频
        /// </summary>
        /// <value>false</value>
        public bool VideoOpened {get;set;}

        /// <summary>
        /// 连接服务器地址
        /// </summary>
        /// <value>http://api2.flyinsono.com/</value>
        public string LoginServerHost { get; set; } = string.Empty;

        /// <summary>
        /// 直播信息
        /// </summary>
        /// <value></value>
        public CacheLiveDataDTO LiveData { get; set; }
    }
    /// <summary>
    /// 直播信息
    /// </summary>
    public class CacheLiveDataDTO
    {
        /// <summary>
        /// 图像宽度
        /// </summary>
        /// <value>1000</value>
        public int Width { get; set; }

        /// <summary>
        /// 图像高度
        /// </summary>
        /// <value>800</value>
        public string Height { get; set; }

        /// <summary>
        /// rtmp推流地址
        /// </summary>
        /// <value></value>
        public string RtmpPushUrl { get; set; } = string.Empty;

        /// <summary>
        /// rtmp拉流地址
        /// </summary>
        /// <value></value>
        public string RtmpPullUrl { get; set; } = string.Empty;

        /// <summary>
        /// http推流地址
        /// </summary>
        /// <value></value>
        public string HttpPullUrl { get; set; } = string.Empty;

        /// <summary>
        /// hls推流地址
        /// </summary>
        /// <value></value>
        public string HlsPullUrl { get; set; } = string.Empty;
    }
}